@@ -6,19 +6,27 @@ use base 'Exporter';
 use Test::More;
 use YAML::PP;
 
-use Lingy::RT;
+use Lingy;
+use Lingy::Lang::RT;
 use Lingy::Common;
 
 use Capture::Tiny qw'capture capture_merged';
 use File::Temp 'tempfile';
 
+BEGIN {
+    if (defined $INC{'Carp/Always.pm'}) {
+        eval "no Carp::Always";
+    }
+}
+
 use lib 'lib', './test/lib', './t/lib';
 
 symlink 't', 'test' if -d 't' and not -e 'test';
 
 my $ypp = YAML::PP->new;
 
-our $rt = Lingy::RT->init;
+RT->init;
+$Lingy::Lang::RT::ready = 0;
 
 $ENV{LINGY_TEST} = 1;
 
@@ -47,14 +55,13 @@ our @EXPORT = qw<
     tempfile
 
     $lingy
-    $rt
     $eg
 
     rep
     run_is
     test
     test_out
-    test_list
+    tests
 
     PPP WWW XXX YYY ZZZ
 >;
@@ -69,10 +76,10 @@ sub import {
 }
 
 sub rep {
-    $rt->rep(@_);
+    RT->rep(@_);
 }
 
-sub test_list {
+sub tests {
     my ($spec) = @_;
     my $list = $ypp->load_string($spec);
     for my $elem (@$list) {
@@ -89,6 +96,7 @@ sub test_list {
 # Test 'rep' for return value or error:
 my $test_i = 0;
 sub test {
+    RT->nextID(10);
     $test_i++;
     if ($ENV{ONLY} and $ENV{ONLY} != $test_i) {
         return;
@@ -96,7 +104,8 @@ sub test {
     my ($input, $want, $label) = @_;
     $label //= "'${\ collapse $input}' -> '${\line $want}'";
 
-    my $got = eval { join("\n", $rt->rep($input)) };
+    $Lingy::Lang::RT::ready = 1;
+    my $got = eval { join("\n", RT->rep($input)) };
     $got = $@ if $@;
     chomp $got;
 
@@ -104,6 +113,8 @@ sub test {
 
     if (ref($want) eq 'Regexp') {
         like $got, $want, $label;
+    } elsif ($want =~ s{^/(.*)/$}{$1}) {
+        like $got, qr/$want/, $label;
     } else {
         is $got, $want, $label;
     }
@@ -113,7 +124,7 @@ sub test_out {
     my ($input, $want, $label) = @_;
     $label //= "'${\ collapse $input}' -> '${\line $want}'";
     my ($got) = Capture::Tiny::capture_merged {
-        $rt->rep($input);
+        RT->rep($input);
     };
     chomp $got;
     chomp $want;
